##############################################################################
### NZBGET POST-PROCESSING SCRIPT										   ###

# Displays contents of nzbget env-vars
#
# This script is useful for development purposes. It simply reveals
# the values of the environment variables that nzbget passes to it.
#
# NOTE: This script requires Python to be installed on your system.

##############################################################################
### OPTIONS                                                                ###

# Dump all nzbget environment variables (yes, no).
#
# If active, all of the nzbget variables will be displayed in messages.
#
# NOTE: This results in a lot of messages added. Can be quite unwieldy.
#DumpAllEnvars=no

# Parent environment variables to dump.
#
# Dump only the specified parent environment variables. The environment
# are separated with commas.
# Example=NZBPP_DIRECTORY, NZBPP_NZBNAME, NZBPP_NZBFILENAME
#ParentEnVars=NZBPP_DIRECTORY, NZBPP_NZBNAME, NZBPP_NZBFILENAME

# Child environment variables to dump.
#
# Dump only the specified child environment variables. The environment
# are separated with commas.
# Example=NZBPP_DIRECTORY, NZBPP_NZBNAME, NZBPP_NZBFILENAME
#ChildEnVars=NZBPP_DIRECTORY, NZBPP_NZBNAME, NZBPP_NZBFILENAME

##############################################################################
### NZBGET POST-PROCESSING SCRIPT										   ###

import sys
from os.path import dirname
sys.path.append(dirname(__file__) + '/videosort/lib')

import os
import string
import traceback
import re
import shutil
import childEnVars

# Exit codes used by NZBGet
POSTPROCESS_SUCCESS=93
POSTPROCESS_NONE=95
POSTPROCESS_ERROR=94

# Check if the script is called from nzbget 11.0 or later
if not 'NZBOP_SCRIPTDIR' in os.environ:
	print('*** NZBGet post-processing script ***')
	print('This script is supposed to be called from nzbget (11.0 or later).')
	sys.exit(POSTPROCESS_ERROR)

dumpAllEnvars=os.environ.get('NZBPO_DUMPALLENVARS', 'no') == 'yes'
child_envars=[x.strip() for x in os.environ.get('NZBPO_CHILDENVARS', '').split(',')]
parent_envars=[x.strip() for x in os.environ.get('NZBPO_PARENTENVARS', '').split(',')]

if len(child_envars) > 0:
	print "*** Child environment variables ***"
	for envar in child_envars:
		print "[INFO] %s: \"%s\"" % (envar, childEnVars.Get(envar))
if len(parent_envars) > 0:
	print "*** Parent environment variables ***"
	for envar in parent_envars:
		print "[INFO] %s: \"%s\"" % (envar, os.environ.get(envar, ''))

if dumpAllEnvars:
	print "*** All parent environment variables ***"
	for k, v in os.environ.items():
		if k.startswith('NZBOP_') or k.startswith('NZBPP_') or k.startswith('NZBPR_'):
			if k.find("PASSWORD") > 0:
				print "%s=%s" % (k, "******")
			else:
				print "%s=%s" % (k, v)

sys.exit(POSTPROCESS_SUCCESS)
